@@ -171,7 +171,7 @@ impl DebianPackagingContext {
         let r = if update_changelog {
             let mut cl = self
                 .edit_file::<debian_changelog::ChangeLog>(Path::new("debian/changelog"), false)?;
-            cl.auto_add_change(&[summary], self.committer.clone(), None, None);
+            cl.auto_add_change(&[summary], self.committer.clone(), Some(chrono::Local::now().into()), None);
             cl.commit()?;
 
             debcommit(
